@@ -20,10 +20,12 @@ tearDown() {
 }
 
 test_new_env_activated () {
-    mkvirtualenv "source"
+    mkvirtualenv "source" >/dev/null 2>&1
+	RC=$?
+	assertEquals "0" "$RC"
     (cd tests/testpackage && python setup.py install) >/dev/null 2>&1
-    cpvirtualenv "source" "destination"
-    rmvirtualenv "source"
+    cpvirtualenv "source" "destination" >/dev/null 2>&1
+    rmvirtualenv "source" >/dev/null 2>&1
     testscript="$(which testscript.py)"
     assertTrue "Environment test script not found in path" "[ $WORKON_HOME/destination/bin/testscript.py -ef $testscript ]"
     testscriptcontent="$(cat $testscript)"
@@ -32,31 +34,66 @@ test_new_env_activated () {
 }
 
 test_virtual_env_variable () {
-    mkvirtualenv "source"
-    cpvirtualenv "source" "destination"
+    mkvirtualenv "source" >/dev/null 2>&1
+    cpvirtualenv "source" "destination" >/dev/null 2>&1
     assertSame "Wrong virtualenv name" "destination" $(basename "$VIRTUAL_ENV")
     assertTrue "$WORKON_HOME not in $VIRTUAL_ENV" "echo $VIRTUAL_ENV | grep -q $WORKON_HOME"
 }
 
-fake_virtualenv () {
+fake_venv () {
+    ###
+    # create a silly file to ensure copy happens
+    ###
     typeset envname="$1"
-    touch "$envname/fake_virtualenv_was_here"
     virtualenv $@
+    touch "$WORKON_HOME/$envname/fake_virtualenv_was_here"
+}
+
+fake_venv_clone () {
+    ###
+    # create a silly file to ensure copy happens
+    ###
+    typeset src_path="$1"
+    touch "$src_path/fake_virtualenv_clone_was_here"
+    virtualenv-clone $@
 }
 
 test_virtualenvwrapper_virtualenv_variable () {
-    mkvirtualenv "source"
-    export VIRTUALENVWRAPPER_VIRTUALENV=fake_virtualenv
-    cpvirtualenv "source" "destination"
+
+    eval 'virtualenvwrapper_verify_virtualenv () { 
+        return 0 
+    }'
+
+    VIRTUALENVWRAPPER_VIRTUALENV=fake_venv
+    assertSame "VIRTUALENVWRAPPER_VIRTUALENV is not set correctly" "$VIRTUALENVWRAPPER_VIRTUALENV" "fake_venv"
+
+    mkvirtualenv "source" >/dev/null 2>&1 
+    assertTrue "Fake file not made in fake_venv" "[ -f "$VIRTUAL_ENV/fake_virtualenv_was_here" ]"
+    cpvirtualenv "source" "destination" >/dev/null 2>&1 
     unset VIRTUALENVWRAPPER_VIRTUALENV
-    assertTrue "wrapper was not run" "[ -f $VIRTUAL_ENV/fake_virtualenv_was_here ]"
+    assertTrue "VIRTUALENVWRAPPER_CLONE did not clone fake file" "[ -f $WORKON_HOME/destination/fake_virtualenv_was_here ]"
+}
+
+test_virtualenvwrapper_virtualenv_clone_variable () {
+
+    eval 'virtualenvwrapper_verify_virtualenv_clone () { 
+        return 0 
+    }'
+
+    VIRTUALENVWRAPPER_VIRTUALENV_CLONE=fake_venv_clone
+    assertSame "VIRTUALENVWRAPPER_VIRTUALENV_CLONE is not set correctly" "$VIRTUALENVWRAPPER_VIRTUALENV_CLONE" "fake_venv_clone"
+
+    mkvirtualenv "source" >/dev/null 2>&1 
+    cpvirtualenv "source" "destination" >/dev/null 2>&1 
+    unset VIRTUALENVWRAPPER_VIRTUALENV_CLONE
+    assertTrue "VIRTUALENVWRAPPER_CLONE did not clone fake file" "[ -f $WORKON_HOME/destination/fake_virtualenv_clone_was_here ]"
 }
 
 test_source_relocatable () {
-    mkvirtualenv "source"
+    mkvirtualenv "source" >/dev/null 2>&1 
     (cd tests/testpackage && python setup.py install) >/dev/null 2>&1
     assertTrue "virtualenv --relocatable \"$WORKON_HOME/source\""
-    cpvirtualenv "source" "destination"
+    cpvirtualenv "source" "destination" >/dev/null 2>&1 
     testscript="$(which testscript.py)"
     assertTrue "Environment test script not the same as copy" "[ $WORKON_HOME/destination/bin/testscript.py -ef $testscript ]"
     assertTrue virtualenvwrapper_verify_active_environment
@@ -64,12 +101,11 @@ test_source_relocatable () {
 }
 
 test_source_does_not_exist () {
-    out="$(cpvirtualenv virtualenvthatdoesntexist foo)"
-    assertSame "$out" "virtualenvthatdoesntexist virtualenv doesn't exist"
+    assertSame "Please provide a valid virtualenv to copy." "$(cpvirtualenv virtualenvthatdoesntexist foo)"
 }
 
 test_hooks () {
-    mkvirtualenv "source"
+    mkvirtualenv "source" >/dev/null 2>&1 
 
     export pre_test_dir=$(cd "$test_dir"; pwd)
 
@@ -89,12 +125,12 @@ test_hooks () {
     echo "#!/bin/sh" > "$WORKON_HOME/postcpvirtualenv"
     echo "echo GLOBAL postcpvirtualenv >> $test_dir/catch_output" > "$WORKON_HOME/postcpvirtualenv"
 
-    cpvirtualenv "source" "destination"
+    cpvirtualenv "source" "destination" >/dev/null 2>&1 
 
     output=$(cat "$test_dir/catch_output")
     workon_home_as_pwd=$(cd $WORKON_HOME; pwd)
 
-    expected="GLOBAL precpvirtualenv $workon_home_as_pwd source destination
+    expected="GLOBAL precpvirtualenv $workon_home_as_pwd $workon_home_as_pwd/source destination
 GLOBAL premkvirtualenv $workon_home_as_pwd destination
 GLOBAL postmkvirtualenv
 GLOBAL postcpvirtualenv"
@@ -108,7 +144,7 @@ GLOBAL postcpvirtualenv"
 test_no_site_packages () {
     # See issue #102
     mkvirtualenv "source" --no-site-packages >/dev/null 2>&1
-    cpvirtualenv "source" "destination"
+    cpvirtualenv "source" "destination" >/dev/null 2>&1 
     ngsp_file="`virtualenvwrapper_get_site_packages_dir`/../no-global-site-packages.txt"
     assertTrue "$ngsp_file does not exist in copied env" "[ -f \"$ngsp_file\" ]"
 }
@@ -118,7 +154,7 @@ test_no_site_packages_default_args () {
     VIRTUALENVWRAPPER_VIRTUALENV_ARGS="--no-site-packages"
     # With the argument, verify that they are not copied.
     mkvirtualenv "source" >/dev/null 2>&1
-    cpvirtualenv "source" "destination"
+    cpvirtualenv "source" "destination" >/dev/null 2>&1 
     ngsp_file="`virtualenvwrapper_get_site_packages_dir`/../no-global-site-packages.txt"
     assertTrue "$ngsp_file does not exist" "[ -f \"$ngsp_file\" ]"
     unset VIRTUALENVWRAPPER_VIRTUALENV_ARGS
@@ -128,7 +164,7 @@ test_no_site_packages_default_behavior () {
     # See issue #102
     # virtualenv 1.7 changed to make --no-site-packages the default
     mkvirtualenv "source" >/dev/null 2>&1
-    cpvirtualenv "source" "destination"
+    cpvirtualenv "source" "destination" >/dev/null 2>&1 
     ngsp_file="`virtualenvwrapper_get_site_packages_dir`/../no-global-site-packages.txt"
     assertTrue "$ngsp_file does not exist in copied env" "[ -f \"$ngsp_file\" ]"
 }
