@@ -31,4 +31,14 @@ function $venvw_name {
 	done
 }
 
+# Set up completion functions to virtualenvwrapper_load
+function virtualenvwrapper_setup_lazy_completion {
+    if [ -n "$BASH" ] ; then
+        complete -o nospace -F virtualenvwrapper_load $(echo ${_VIRTUALENVWRAPPER_API})
+    elif [ -n "$ZSH_VERSION" ] ; then
+        compctl -K virtualenvwrapper_load $(echo ${_VIRTUALENVWRAPPER_API})
+    fi
+}
+
 virtualenvwrapper_setup_lazy_loader
+virtualenvwrapper_setup_lazy_completion
